{ config, pkgs, lib, ... }:
{
  imports = [
    ./remote.nix
    ./gnome.nix
    ./xfce.nix
  ];

  services.xserver = {
    enable = true;
    displayManager.gdm = {
      enable = true;
      wayland = true;
    };
    videoDrivers = [ "nvidia" ];
    xkbOptions = "ctrl:nocaps";
    layout = "no,us";
    xkbVariant = "intl";
  };

  #hardware.nvidia.modesetting.enable = true; # TODO: Fix this. Steam crashes, and textures/fonts unload when suspended.
  hardware.keyboard.zsa.enable = true;
  environment.sessionVariables.NIXOS_OZONE_WL = "1";

  environment.systemPackages = with pkgs; [
    xclip
  ];

  hardware.opengl.enable = true;

  # Audio
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };
  hardware.pulseaudio.enable = false;

  # Fonts
  fonts = {
    fontDir.enable = true;
    packages = with pkgs; [
      noto-fonts
      noto-fonts-emoji
      noto-fonts-cjk-sans
      font-awesome
      fira-code
      hack-font
      (nerdfonts.override {
        fonts = [
          "Hack"
        ];
      })
    ];
  };

  # Dark mode
  home-manager.users.felixalb = {
    dconf.settings = {
      "org/gnome/desktop/interface" = {
        color-scheme = "prefer-dark";
      };
    };

    gtk = {
      enable = true;
      theme = {
        name = "Adwaita-dark";
        package = pkgs.gnome.gnome-themes-extra;
      };
    };
  };

  qt = {
    enable = true;
    platformTheme = "gnome";
    style = "adwaita-dark";
  };

  # Misc:
  xdg.portal = {
    enable = true;
    wlr.enable = true;
  };
  location.provider = "geoclue2";
  security.polkit.enable = true;
  services.flatpak.enable = true;
  services.redshift.enable = true;
  users.users."felixalb".packages = [ pkgs.flatpak ];
}
